<?php

class FixAndFlipCalculator
{

    private $shortcode_rendered = false;

    function __construct()
    {
        // Register Styles and Scripts
        add_action('wp_enqueue_scripts', array($this, 'register_scripts'));

        // Register Shortcode
        add_shortcode('FaF_calculator', array($this, 'calculator_shortcode'));

        // Register Widget
        add_action('widgets_init', array($this, 'load_widget'));

    }


    function calculator_shortcode()
    {
        if ($this->shortcode_rendered)
            return '';

        // Prevent Shortcode to get rendered twice
        $this->shortcode_rendered = true;

        $this->enqueue_scripts();

        return $this->render_calculator();

    }

    function load_widget()
    {

        require_once FAF_CALCULATOR_PLUGIN_PATH . 'includes/widget.php';
        register_widget('FAFCalculator');

    }

    function enqueue_scripts()
    {
        wp_enqueue_style('faf_calculator_style');
        wp_enqueue_style('faf_calculator_bootstrap');

        wp_enqueue_script('faf_calculator_script');
        wp_enqueue_script('jquery');

    }

    function render_calculator()
    {

        return '
            <div id="faf-calculator-wrapper">
                <div class="two-column">
                    <div class="column">
                        <form>
                            <h2>Acquisition Costs</h2>
                            <div class="form-row">
                                <div class="form-group col-md-12">
                                    <label for="inputPurchasePrice">Purchase Price (Incl. Taxes)</label>
                                    <input type="text" class="form-control" id="inputPurchasePrice" value="575000">
                                </div>
                                <div class="form-group col-md-12">
                                    <label for="inputPurchaseClosingCosts">Closing Costs</label>
                                    <input type="number" class="form-control" id="inputPurchaseClosingCosts" value="25000">
                                </div>
                            </div>
                            <h2>Disposal Costs</h2>
                            <div class="form-row">
                                <div class="form-group col-md-12">
                                    <label for="inputSaleClosingCosts">Sale Closing Costs  (Incl. Taxes)</label>
                                    <input type="number" class="form-control" id="inputSaleClosingCosts" value="35000">
                                </div>
                                <div class="form-group col-md-12">
                                    <label for="inputCommission">Agent Commissions (%)</label>
                                    <input type="text" class="form-control" id="inputCommission" value="7">
                                </div>
                            </div>
                            <h2>Estimates</h2>
                            <div class="form-row">
                                <div class="form-group col-md-12">
                                    <label for="inputARV">After Repair Value (ARV)</label>
                                    <input type="number" class="form-control" id="inputARV" value="785000">
                                </div>
                                <div class="form-group col-md-12">
                                    <label for="inputDesiredProfit">Desired Profit</label>
                                    <input type="number" class="form-control" id="inputDesiredProfit" value="25000">
                                </div>
                            </div>
                            <h2>Rehab Estimates</h2>
            
                            <div class="form-group">
                                <div class="form-group">
                                    <label for="inputRepair">Repair Costs</label>
                                    <input type="number" class="form-control" id="inputRepair" value="27500">
                                </div>
            
                            </div>
                            <div class="form-row">
                                <div class="form-group col-md-12">
                                    <label for="inputHoldingCost">Monthly Holding Cost</label>
                                    <input type="number" class="form-control" id="inputHoldingCost" value="1220">
                                </div>
                                <div class="form-group col-md-12">
                                    <label for="inputHoldingTime">Holding Time (Months)</label>
                                    <input type="number" class="form-control" id="inputHoldingTime" value="10">
                                </div>
                            </div>
            
                            <button type="button" id="calculateflip" class="btn btn-primary btn-block"
                                    onclick="calculateMaxOffer(flipChart); updateAll(flipChart)">Calculate Results
                            </button>
            
                        </form>
                    </div>
                    <div class="column">
                        <div class="estimatedProfit">
                            <p class="estimateHighlight">Estimated Profit</p>
                            <p class="totalEstimate" id="est-profit">$</p>
                            <div class="bottomTotals">
                                <p class="estimateHighlight">Max Offer Price <span id="max-offer-price">$</span></p>
                                <div class="divider"></div>
                                <p class="estimateHighlight">Rehab and Expenses <span id="rehab-plus-expenses">$</span></p>
                            </div>
                        </div>
            
                        <div class="chartContainer">
                            <div class="chartjs-size-monitor">
                                <div class="chartjs-size-monitor-expand">
                                    <div class=""></div>
                                </div>
                                <div class="chartjs-size-monitor-shrink">
                                    <div class=""></div>
                                </div>
                            </div>
                            <canvas id="flipChart" style="display: block; width: 480px; height: 240px;"
                                    class="chartjs-render-monitor" width="480" height="240"></canvas>
                        </div>
                        <div class="attribution">
                            <small>Powered by <a href="https://www.htag.com.au/" target="_blank">HtAG Property Investment Platform</a></small>
                        </div>
                    </div>
                </div>
            </div>
        ';
    }

    function register_scripts()
    {
        // Register Styles
        wp_register_style('faf_calculator_style', FAF_CALCULATOR_PLUGIN_URL . 'assets/style.css');
        wp_register_style('faf_calculator_bootstrap', FAF_CALCULATOR_PLUGIN_URL . 'libs/bootstrap.min.css');

        // Register Scripts
        wp_register_script('faf_calculator_script', FAF_CALCULATOR_PLUGIN_URL . 'assets/shortcode.js');
        wp_enqueue_script('faf_chart_js', FAF_CALCULATOR_PLUGIN_URL . 'libs/Chart.js');
    }


}